BaseRequest class abstract

Constructors

BaseRequest()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBaseUrl(bool isDebug) → String
getLanguageCode() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareForBody() → String?
prepareForBodyWithMap() → Map<String, dynamic>?
prepareForHeader() → String
prepareForHeaderWithMap() → Map<String, String?>
prepareForMethod() → int
prepareForPath() → String?
prepareForZone() → String?
toProxyData() → NIMPassThroughProxyData
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

baseUrl → const String
baseUrlTest → const String