BaseResponse<T> class

Constructors

BaseResponse(int code, dynamic error, NIMPassThroughProxyData? proxyData, {T? convertor(Map<String, dynamic> json)?})

Properties

code → int
final
convertor ↔ T? Function(Map<String, dynamic> json)?
json转换器
getter/setter pair
data ↔ T?
数据由 proxyData 中的 body 转换而来
getter/setter pair
dataCode ↔ int
getter/setter pair
dataMsg ↔ String?
getter/setter pair
dataRequestId ↔ String?
getter/setter pair
error → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
proxyData → NIMPassThroughProxyData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDataContent(NIMPassThroughProxyData? data) → String
isSuccessful() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

tag → const String